#include <LiquidCrystal.h>
#include <DHT.h>
#include <DHT_U.h>
#include <TimerOne.h>

#define DHTPIN 13
#define DHTTYPE DHT11
DHT dht(DHTPIN, DHTTYPE);

LiquidCrystal lcd(12, 11, 10, 9, 8, 7);
//Variables----------------------------
//DHT
float TValue = 0;
float HValue = 0;

float THigh=25.0;
float TLow=20.0;

float HHigh=60.0;
float HLow=40.0;

//LCD
byte C[8] = {
  0b00000,
  0b00100,
  0b01010,
  0b00100,
  0b00000,
  0b00000,
  0b00000,
  0b00000
};

//RGB

#define T_LED_R 6
#define T_LED_G 5
#define T_LED_B 4
#define H_LED_R 3
#define H_LED_G 2
#define H_LED_B 1

int ledPins[]={6,5,4,3,2,1};

//-------------------------------------
void setup() {
  lcd.begin(16, 2);
  lcd.createChar(0, C);

  dht.begin();
  
  for(int i=0;i<6;i++){
    digitalWrite(ledPins[i],LOW);
    pinMode(ledPins[i],OUTPUT);
  }

  Timer1.initialize(100000);
  Timer1.attachInterrupt(controlTH); 
}

void loop() {
  TValue = dht.readTemperature();
  HValue = dht.readHumidity();

  refreshScreen();

}

void refreshScreen() {
  lcd.setCursor(0, 0);
  lcd.print("T:");
  lcd.print(TValue);
  lcd.write(byte(0));
  lcd.print("C");
  lcd.setCursor(0, 1);
  lcd.print("H:%");
  lcd.print(HValue);
}

void controlTH(){
  if(TValue>THigh){
    digitalWrite(T_LED_R,HIGH);
    digitalWrite(T_LED_G,LOW);
    digitalWrite(T_LED_B,LOW);
  }else if(TValue<TLow){
    digitalWrite(T_LED_R,LOW);
    digitalWrite(T_LED_G,LOW);
    digitalWrite(T_LED_B,HIGH);    
  }else{
    digitalWrite(T_LED_R,LOW);
    digitalWrite(T_LED_G,HIGH);
    digitalWrite(T_LED_B,LOW);    
  }

  if(HValue>HHigh){
    digitalWrite(H_LED_R,HIGH);
    digitalWrite(H_LED_G,LOW);
    digitalWrite(H_LED_B,LOW);    
  }else if(HValue<HLow){
    digitalWrite(H_LED_R,LOW);
    digitalWrite(H_LED_G,LOW);
    digitalWrite(H_LED_B,HIGH);      
  }else{
    digitalWrite(H_LED_R,LOW);
    digitalWrite(H_LED_G,HIGH);
    digitalWrite(H_LED_B,LOW);      
  }
}

